Compute the Pearson correlation matrix between columns of two sparse matrices.
Details
Originally from http://stackoverflow.com/questions/5888287/running-cor-or-any-variant-over-a-sparse-matrix-in-r and the qlcMatrix & Signac packages.
Compute the Pearson correlation matrix between columns of two sparse matrices.
Originally from http://stackoverflow.com/questions/5888287/running-cor-or-any-variant-over-a-sparse-matrix-in-r and the qlcMatrix & Signac packages.