Convert a single-cell expression matrix (i.e., genes by cells) to a pseudobulk matrix by summarizing counts within biological replicates. This function is
Usage
to_pseudobulk(
input,
meta = NULL,
replicate_col = "replicate",
cell_type_col = "cell_type",
label_col = "label",
min_cells = 3,
min_reps = 2,
min_features = 0,
external = T
)Arguments
- input
a single-cell matrix to be converted, with features (genes) in rows and cells in columns. Alternatively, a
Seurat,monocole3, or orSingleCellExperimentobject can be directly input.- meta
the accompanying meta data whereby the rownames match the column names of
input.- replicate_col
the vector in
metacontaining the replicate information. Defaults toreplicate.- cell_type_col
the vector in
metacontaining the cell type information. Defaults tocell_type.- label_col
the vector in
metacontaining the experimental label. Defaults tolabel.- min_cells
the minimum number of cells in a cell type to retain it. Defaults to
3.- min_reps
the minimum number of replicates in a cell type to retain it. Defaults to
2.- min_features
the minimum number of expressing cells (or replicates) for a gene to retain it. Defaults to
0.